@@ -23,7 +23,7 @@ my $user = $opts{u} or
     die "No OpenResty account name specified via option -u\n";
 my $password = $opts{p} or
     die "No OpenResty account's Admin password specified via option -p\n";
-my $server = $opts{s} || 'http://resty.eeeeworks.org';
+my $server = $opts{s} || 'http://api.openresty.org';
 
 my ($blog_name, $blog_home);
 if ($user eq 'agentzh') {
